@@ -16,10 +16,8 @@ __all__ = ['Banshee',
            'gnome-search-tool',
            'gnome-shell',
            'gnome-window-properties',
-           'gtk-window-decorator',
            'Instantbird',
            'liferea',
-           'metacity',
            'Mozilla',
            'notification-daemon',
            'notify-osd',
